<?php

class ActivityGateway {
    private $connection;

    public function __construct(Connection $connection) {
        $this->connection = $connection;
    }

    public function getActivity() {
        $query = "SELECT * FROM Activity";
        return $this->connection->executeWithErrorHandling($query);
    }

    public function getActivityById($activityId) {
        $query = "SELECT * FROM Activity WHERE idActivity = :id";
        $params = [':id' => [$activityId, PDO::PARAM_INT]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getActivityByType($type) {
        $query = "SELECT * FROM Activity WHERE type = :type";
        $params = [':type' => [$type, PDO::PARAM_STR]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getActivityByDate($date) {
        $query = "SELECT * FROM Activity WHERE date = :date";
        $params = [':date' => [$date, PDO::PARAM_STR]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getActivityByTimeRange($startTime, $endTime) {
        $query = "SELECT * FROM Activity WHERE heureDebut >= :startTime AND heureFin <= :endTime";
        $params = [
            ':startTime' => [$startTime, PDO::PARAM_STR],
            ':endTime' => [$endTime, PDO::PARAM_STR]
        ];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getActivityByEffort($effortRessenti) {
        $query = "SELECT * FROM Activity WHERE effortRessenti = :effort";
        $params = [':effort' => [$effortRessenti, PDO::PARAM_INT]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getActivityByVariability($variabilite) {
        $query = "SELECT * FROM Activity WHERE variabilite = :variability";
        $params = [':variability' => [$variabilite, PDO::PARAM_INT]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getActivityByTemperature($temperatureMoyenne) {
        $query = "SELECT * FROM Activity WHERE temperatureMoyenne = :temperature";
        $params = [':temperature' => [$temperatureMoyenne, PDO::PARAM_INT]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }
}

?>
